local mymodule = {}

-- Load libraries
modelfunctions = require("modelfunctions")
fs = require("acf.fs")
format = require("acf.format")

-- Set variables
local confdfile = "/etc/conf.d/postgresql"
local processname = "postgresql"
local packagename = "postgresql"

local path = "PATH=/usr/local/bin:/usr/bin:/bin:/usr/local/sbin:/usr/sbin:/sbin "

local datadirectory
local filelist

function mymodule.set_processname(p)
	processname = p
	confdfile = "/etc/conf.d/"..processname
end

-- ################################################################################
-- LOCAL FUNCTIONS

local determinefilelist = function()
	if not filelist then
		datadirectory = format.get_ini_entry(fs.read_file(confdfile) or "", "", "PGDATA")
		filelist = fs.find_files_as_array(".*%.conf", datadirectory)
	end
	return filelist
end

-- ################################################################################
-- PUBLIC FUNCTIONS

function mymodule.get_startstop(self, clientdata)       
	return modelfunctions.get_startstop(processname)
end

function mymodule.startstop_service(self, startstop, action)
	return modelfunctions.startstop_service(startstop, action)
end

function mymodule.getstatus()
	return modelfunctions.getstatus(processname, packagename, "Postgresql Status")
end

function mymodule.getstatusdetails()
	return cfe({ type="longtext", value="", label="Postgresql Status Details" })
end

function mymodule.getfilelist()
	local listed_files = {}

	for i,name in ipairs(determinefilelist()) do
		local filedetails = fs.stat(name) or {}
		table.insert ( listed_files , {filename=name, mtime=filedetails.mtime or "---", filesize=filedetails.size or "0"} )
	end

	table.sort(listed_files, function (a,b) return (a.filename < b.filename) end )

	return cfe({ type="list", value=listed_files, label="Postgresql File List" })
end

function mymodule.getfiledetails(filename)
	return modelfunctions.getfiledetails(filename, determinefilelist())
end

function mymodule.updatefiledetails(self, filedetails)
	return modelfunctions.setfiledetails(self, filedetails, determinefilelist())
end

return mymodule
